@@ -65,15 +65,22 @@ void DialogViewConfigurationItem::refreshItem()
   setData(Qt::DisplayRole, _name);
 }
 
+/**
+ * Serializer. Used for DnD.
+ */
 static QDataStream & operator<< ( QDataStream & s, const DialogViewConfigurationItem & item ) {
     s << item._id;
     s << item._shown;
     s << item._name;
     s << item._splitted;
     s << item._iconName;
- //kDebug() << "<< unserialize << " << s;
+ //kDebug() << "<< serialize << " << s;
     return s;
 }
+
+/**
+ * Deserializer. Used for DnD.
+ */
 static QDataStream & operator>> ( QDataStream & s, DialogViewConfigurationItem & item ) {
   QString id;
   s >> id;
@@ -90,7 +97,7 @@ static QDataStream & operator>> ( QDataStream & s, DialogViewConfigurationItem &
   QString iconName;
   s >> iconName;
   item._iconName = iconName;
- //kDebug() << ">> serialize >> " << id << name << iconName;
+ //kDebug() << ">> deserialize >> " << id << name << iconName;
   return s;
 }
 
@@ -439,12 +446,7 @@ void DialogViewConfiguration::prepareControls(QAbstractItemModel* model, bool is
                 newCtl->id =  '^' + ctlId + '$'; // Replace the (possible generic) regexp by the actual ID
                 // We have made this an an actual control. As it is derived (from e.g. ".*") it is NOT mandatory.
                 newCtl->setMandatory(false);
-                if ( isActiveView ) {
-                    newCtl->show = "simple";
-                }
-                else {
-                    newCtl->show = "extended";
-                }
+                newCtl->setVisible(isActiveView);
                 newCtlSet.push_back(newCtl);
 //                 kDebug() << "Added to new ControlSet (done): " << newCtl->id;
                 break;
