@@ -38,6 +38,7 @@ class MixDevice;
 #include "core/mixdevice.h"
 #include "core/mixset.h"
 #include "gui/guiprofile.h"
+#include "gui/mixdevicewidget.h"
 
 /**
   * The ViewBase is a virtual base class, to be used for subclassing the real Mixer Views.
@@ -86,7 +87,7 @@ public:
     virtual QWidget* add(shared_ptr<MixDevice>) = 0;
 
     // This method is called after a configuration update (show/hide controls, split/unsplit).
-    virtual void configurationUpdate(); // TODO remove
+    virtual void configurationUpdate() = 0;
 
     void load(KConfig *config);
     void save(KConfig *config);
@@ -117,6 +118,7 @@ public:
    
    GUIProfile* guiProfile() { return GUIProfile::find(_guiProfileId); };
    GUIComplexity getGuiComplexity() { return guiComplexity; };
+   ProfControl* findMdw(const QString& id);
    ProfControl* findMdw(const QString& mdwId, QString requestedGuiComplexityName);
 
    
@@ -164,6 +166,11 @@ signals:
 
 private:
    QString      m_viewId;
+   void updateMediaPlaybackIcons();
+
+private slots:
+   void guiVisibilitySlot(MixDeviceWidget* source, bool enable);
+
 };
 
 #endif
